@@ -13,12 +13,16 @@ use RadioMobile::Config::StyleNetworksPropertiesParser;
 use RadioMobile::Config::Pictures;
 use RadioMobile::Config::LandHeightParser;
 
-our $VERSION    = '0.01';
+our $VERSION    = '0.10';
 
 __PACKAGE__->valid_params(
 							stylenetworksproperties	=> { isa  =>
 								'RadioMobile::Config::StyleNetworksProperties'},
 							pictures	=> { isa  => 'RadioMobile::Config::Pictures'},
+							landheight => {type => SCALAR, 
+								default => 'C:\Program Files (x86)\Radio Mobile\landheight.dat'},
+							mapfilepath => {type => SCALAR,  
+								default => ''},
 );
 __PACKAGE__->contained_objects(
 	stylenetworksproperties => 'RadioMobile::Config::StyleNetworksProperties',
@@ -43,6 +47,15 @@ sub parse_mapfilepath {
 	$p->parse;
 }
 
+sub write_mapfilepath {
+	my $s	= shift;
+	my $p	= new RadioMobile::Config::MapFileParser(
+					bfile 	=> $s->container->bfile,
+					config	=> $s
+			);
+	$p->write;
+}
+
 
 sub parse_stylenetworks {
 	my $s	= shift;
@@ -53,6 +66,15 @@ sub parse_stylenetworks {
 	$p->parse;
 }
 
+sub write_stylenetworks {
+	my $s	= shift;
+	my $p	= new RadioMobile::Config::StyleNetworksPropertiesParser(
+					bfile   => $s->container->bfile,
+					config	=> $s
+	);
+	$p->write;
+}
+
 sub parse_landheight {
 	my $s	= shift;
 	my $p	= new RadioMobile::Config::LandHeightParser(
@@ -62,6 +84,15 @@ sub parse_landheight {
 	$p->parse;
 }
 
+sub write_landheight {
+	my $s	= shift;
+	my $p	= new RadioMobile::Config::LandHeightParser(
+					bfile 	=> $s->container->bfile,
+					config	=> $s
+			);
+	$p->write;
+}
+
 sub dump {
 	my $s	= shift;
 	return Data::Dumper::Dumper($s) unless (@_);
@@ -75,4 +106,5 @@ sub dump {
 	return $ret;
 }
 
+
 1;
