@@ -7,23 +7,26 @@ use Class::Container;
 use Params::Validate qw(:types);
 use base qw(Class::Container);
 
-our $VERSION    = '0.01';
+our $VERSION    = '0.10';
+
+use constant ITEMS  => qw/isIn role height azimut direction elevation/;
+use constant DEFAULTS => qw/0 0 0 0 0 0/;
 
 __PACKAGE__->valid_params(
 							unit	=> { isa  => 'RadioMobile::Unit'},
 							net	=> { isa  => 'RadioMobile::Net'},
+							map {(ITEMS)[$_] =>{type=>SCALAR, default=> (DEFAULTS)[$_]}} (0..(ITEMS)-1),
 );
 __PACKAGE__->contained_objects(
 	'unit'	=> 'RadioMobile::Unit',
 	'net'	=> 'RadioMobile::Net',
 );
 
-use Class::MethodMaker [ scalar => [qw/unit net isIn role system height azimut direction elevation/] ];
+use Class::MethodMaker [ scalar => [ITEMS,qw/unit net system/] ];
 
 sub new {
 	my $package = shift;
 	my $s = $package->SUPER::new(@_);
-	$s->reset;
 	return $s;
 }
 
@@ -34,10 +37,8 @@ sub dump {
 
 sub reset {
 	my $s	= shift;
-	$s->isIn(0);
-	$s->azimut(0);
-	$s->direction('');
-	$s->elevation(0);
+	map {$s->{(ITEMS)[$_]} = (DEFAULTS)[$_]} (0..(ITEMS)-1);
+
 }
 
 1;
